@@ -16,6 +16,7 @@ utils::globalVariables(c(
 #' @param prec Boolean. Add precipitation curve to the plot? Defaults to `FALSE`. If both `temp = TRUE` and `prec = TRUE`, then the axis is drawn for precipitation.
 #' @param span Integer number of days to accumulate precipitation for plotting.
 #' @param print Boolean. Print plot? Defaults to `TRUE`. Use `FALSE` if you want to tweak the plot aesthetics before plotting.
+#' @param yrange Boolean. Y range for each plot. Defaults to `'uniform'` which means that the highest value of Y axis is the same on all plots and is determined by the highest discharge for all years to be plotted. Use `'each'` if you want each plot to have its own maximum along Y axis determined by the highest discharge for this year. You can also use any numeric value `ymax` in a form `yrange = ymax` to determine your own Y scale maximum for all plots.
 #'
 #' @return `list` of `ggplot2` objects, one for each year, representing the hydrograph separation
 #' 
@@ -24,7 +25,8 @@ utils::globalVariables(c(
 #' @example inst/examples/gr_plot_sep.R
 #' 
 gr_plot_sep <- function(df, years = NULL, layout = as.matrix(1), 
-                        pagebreak = FALSE, temp = FALSE, prec = FALSE, span = 5, print = TRUE){
+                        pagebreak = FALSE, temp = FALSE, prec = FALSE, 
+                        span = 5, print = TRUE, yrange = 'uniform'){
   
   if (grenv$loc == 'RU') {
     Sys.setenv(LANGUAGE="ru")
@@ -50,22 +52,23 @@ gr_plot_sep <- function(df, years = NULL, layout = as.matrix(1),
   if (grenv$loc != 'EN')
     labs = gr_unescape(labs)
   
-  df = df %>% dplyr::mutate(Year = lubridate::year(Date))
+  df = df |> dplyr::mutate(Year = lubridate::year(Date))
   
   if(!is.null(years)){
-    df = df %>% dplyr::filter(Year %in% unique(c(years, years + 1)))
+    df = df |> dplyr::filter(Year %in% unique(c(years, years + 1)))
   } else {
-    years = df %>% dplyr::pull(Year) %>% unique() %>% sort() 
+    years = df |> dplyr::pull(Year) |> unique() |> sort() 
   }
   
-  yrs = df %>% dplyr::group_by(.data$Year) %>% 
-    dplyr::summarise(nydate =Date[which(Qspri>0)[1]],
-                     dspend = max(Date[which(Qspri>0)])) %>% 
+  yrs = df |> 
+    dplyr::group_by(.data$Year) |> 
+    dplyr::summarise(nydate = Date[which(Qspri>0)[1]],
+                     dspend = max(Date[which(Qspri>0)])) |> 
     dplyr::filter(!is.na(nydate))
   
   n = nrow(yrs)
   
-  max.runoff = max(df$Q, na.rm = TRUE)
+  max.runoff = ifelse(is.numeric(yrange), yrange, max(df$Q, na.rm = TRUE))
   max.temp = max(df$Temp, na.rm = TRUE)
   min.temp = min(df$Temp, na.rm = TRUE)
   
@@ -75,7 +78,6 @@ gr_plot_sep <- function(df, years = NULL, layout = as.matrix(1),
     max.prec = max(df$Preccum, na.rm = TRUE)
   }
   
-  
   coef_temp = (max.temp - min.temp) / max.runoff
   coef_prec = max.prec / max.runoff
   
@@ -117,13 +119,21 @@ gr_plot_sep <- function(df, years = NULL, layout = as.matrix(1),
       }
     }
     
-    yeardata = df %>%  
+    yeardata = df |>   
       dplyr::filter(dplyr::between(.data$Date, begin.date-1, end.date))
     
-    graphdata = yeardata %>% 
+    if (yrange == 'each') {
+      max.runoff = max(yeardata$Q, na.rm = TRUE)
+      max.temp = max(yeardata$Temp, na.rm = TRUE)
+      max.prec = max(yeardata$Prec, na.rm = TRUE)
+      coef_temp = (max.temp - min.temp) / max.runoff
+      coef_prec = max.prec / max.runoff
+    } 
+    
+    graphdata = yeardata |>  
       tidyr::pivot_longer(c(.data$Qthaw,Qrain,Qspri,Qbase),
-                          names_to = "Runtype", values_to = "Runoff") %>%
-                          # factor_key=TRUE) %>% 
+                          names_to = "Runtype", values_to = "Runoff") |> 
+                          # factor_key=TRUE) |> 
       dplyr::mutate(Runoff = ifelse(.data$Runoff < 0, 0,Runoff))
     
     graphdata$Runtype = factor(graphdata$Runtype,
@@ -137,7 +147,7 @@ gr_plot_sep <- function(df, years = NULL, layout = as.matrix(1),
                fill = 'black',
                alpha = 0.1) +
       ggplot2::geom_area(data = graphdata, mapping = ggplot2::aes(x =Date, y =Runoff, fill =Runtype),
-                         size = 0.1, color = 'black', na.rm = TRUE) + 
+                         linewidth = 0.1, color = 'black', na.rm = TRUE) + 
       # geom_line(aes(group = Runtype), size = 0.1, color = 'black') +
       ggplot2::coord_cartesian(ylim = c(0, max.runoff), clip = 'off') +
       ggplot2::scale_fill_manual(values = c("coral2", "deepskyblue3", "darkturquoise", "bisque4"), 
@@ -156,13 +166,13 @@ gr_plot_sep <- function(df, years = NULL, layout = as.matrix(1),
                                                                      name = paste0(labs$preccum, ' (', span, ' ',  labs$day, ')'))) +
             ggplot2::geom_line(data = yeardata,
                                mapping = ggplot2::aes(x =Date, y =Preccum / coef_prec),
-                               color = 'springgreen1', size = 0.5, na.rm = TRUE)
+                               color = 'springgreen1', linewidth = 0.5, na.rm = TRUE)
         } else {
           g = g +
             ggplot2::scale_y_continuous(sec.axis = ggplot2::sec_axis(~ . * coef_prec, name = labs$prec)) +
             ggplot2::geom_line(data = yeardata,
                                mapping = ggplot2::aes(x =Date, y =Prec / coef_prec),
-                               color = 'springgreen1', size = 0.5, na.rm = TRUE)
+                               color = 'springgreen1', linewidth = 0.5, na.rm = TRUE)
         }
     }
     
@@ -175,21 +185,21 @@ gr_plot_sep <- function(df, years = NULL, layout = as.matrix(1),
                              mapping = ggplot2::aes(x =Date, 
                                                     y = (.data$Temp - min.temp) / coef_temp),
                              color = 'purple',
-                             size = 0.5, 
+                             linewidth = 0.5, 
                              na.rm = TRUE) +
           ggplot2::geom_line(data = yeardata,
                              mapping = ggplot2::aes(x =Date, 
                                                     y = (.data$Posit - min.temp) / coef_temp),
                              color = 'red',
-                             size = 0.5,
+                             linewidth = 0.5,
                              na.rm = TRUE) +
           ggplot2::geom_line(data = yeardata,
                              mapping = ggplot2::aes(x =Date, 
                                                     y = (.data$Negat - min.temp) / coef_temp),
                              color = 'blue',
-                             size = 0.5,
+                             linewidth = 0.5,
                              na.rm = TRUE) +
-          ggplot2::geom_hline(yintercept = - min.temp / coef_temp, color = "purple", size = 0.3, linetype = "dotted") +
+          ggplot2::geom_hline(yintercept = - min.temp / coef_temp, color = "purple", linewidth = 0.3, linetype = "dotted") +
           ggplot2::labs(color = NULL)
         
         if (!prec)
@@ -197,8 +207,8 @@ gr_plot_sep <- function(df, years = NULL, layout = as.matrix(1),
     }
     
     g = g + 
-      ggplot2::geom_vline(xintercept = dspstart-1, color = "black", size=0.3) +
-      ggplot2::geom_vline(xintercept = dspend+1, color = "black", size=0.3) +
+      ggplot2::geom_vline(xintercept = dspstart-1, color = "black", linewidth=0.3) +
+      ggplot2::geom_vline(xintercept = dspend+1, color = "black", linewidth=0.3) +
       ggplot2::geom_label(data = data.frame(x = dspstart, 
                                             y = 0.9 * max.runoff, 
                                             text = format(dspstart, format="%d-%m")),
@@ -281,28 +291,28 @@ gr_plot_vars <- function(df, ..., tests = NULL, exclude = NULL, smooth = TRUE,
   if (grenv$loc != 'EN')
     labs = gr_unescape(labs)
   
-  fields = rlang::exprs(...) %>% as.character()
+  fields = rlang::exprs(...) |> as.character()
   
   if(length(fields) == 0)
-    fields = params_out %>% 
-      dplyr::filter(.data$Order != 0) %>% 
-      dplyr::arrange(.data$Order) %>% 
+    fields = params_out |>  
+      dplyr::filter(.data$Order != 0) |>  
+      dplyr::arrange(.data$Order) |>  
       dplyr::pull(.data$Name)
   
-  prms = params_out %>% 
-    dplyr::filter(.data$Name %in% fields) %>% 
+  prms = params_out |> 
+    dplyr::filter(.data$Name %in% fields) |> 
     dplyr::slice(match(fields,Name))
   
   if (is.logical(tests))
     if (tests == TRUE)
       tests = gr_test_vars(df, ...)
   
-  df = df %>% 
+  df = df |> 
     dplyr::mutate_if(params_out$Type == 'Date', function(X) { 
       lubridate::year(X) = 2000 
       return(X)
-    }) %>%  
-    dplyr::mutate_if(params_out$Winter == 1, replace_year) %>% 
+    }) |> 
+    dplyr::mutate_if(params_out$Winter == 1, replace_year) |> 
     dplyr::mutate_at(dplyr::vars(-.data$Year1, -.data$Year2), function(X) {
       structure(ifelse(df$Year1 %in% exclude, NA, X), class = class(X))
     }) # EXCLUDE YEARS
@@ -342,7 +352,7 @@ gr_plot_vars <- function(df, ..., tests = NULL, exclude = NULL, smooth = TRUE,
       ggplot2::theme(plot.title = ggplot2::element_text(size=12, lineheight=.8, face="bold"),
             panel.background = ggplot2::element_rect(fill = prms$Color[i],
                                             colour = prms$Color[i],
-                                            size = 0.5, linetype = "solid"))
+                                            linewidth = 0.5, linetype = "solid"))
     if (!is.null(exclude)) {
       g = g + 
         ggplot2::labs(caption = paste('Excluded years:', paste(exclude, collapse = ', '))) +
@@ -364,7 +374,7 @@ gr_plot_vars <- function(df, ..., tests = NULL, exclude = NULL, smooth = TRUE,
                        ifelse(tests$ptt[[varname]]$p.value > 0.05, 'dashed', 'solid'))
         g = g +
           ggplot2::geom_vline(xintercept = tests$year[varname], color = "red",
-                     size=0.5, linetype = ltype) +
+                              linewidth=0.5, linetype = ltype) +
           ggplot2::annotate("text", label = tests$year[varname],
                    x = tests$year[varname] + 4, y = tests$maxval[[varname]],
                    size = 4, colour = "red")
@@ -374,7 +384,7 @@ gr_plot_vars <- function(df, ..., tests = NULL, exclude = NULL, smooth = TRUE,
         ts_ltype = ifelse(mblm::summary.mblm(tests$ts_fit[[varname]])$coefficients[2, 4] > 0.05, 'dashed', 'solid')
         
         g = g + ggplot2::geom_abline(intercept = coef(tests$ts_fit[[varname]])[1], slope = coef(tests$ts_fit[[varname]])[2],
-                            color = 'red', size = 1, linetype = ts_ltype)
+                            color = 'red', linewidth = 1, linetype = ts_ltype)
       }
 
       fixedstr = ifelse(tests$fixed_year, '',
@@ -401,10 +411,10 @@ gr_plot_vars <- function(df, ..., tests = NULL, exclude = NULL, smooth = TRUE,
     if (prms$Chart[i] == 'line') {
       g = g + ggplot2::geom_line() + ggplot2::geom_ribbon(ggplot2::aes_string(ymin = 0, ymax = prms$Name[i]), alpha = 0.3)
     } else if (prms$Chart[i] == 'point') {
-      g = g + ggplot2::geom_point(size = 1.5) + ggplot2::geom_line(size = 0.2)
+      g = g + ggplot2::geom_point(size = 1.5) + ggplot2::geom_line(linewidth = 0.2)
       date_labels = "%b"
     } else if (prms$Chart[i] == 'plate') {
-      g = g + ggplot2::geom_point(shape = 15, size = 1.5) + ggplot2::geom_step(size = 0.2)
+      g = g + ggplot2::geom_point(shape = 15, size = 1.5) + ggplot2::geom_step(linewidth = 0.2)
       date_labels = "%b"
     } else if (prms$Chart[i] == 'step') {
       g = g + ggplot2::geom_step() + ggplot2::geom_rect(ggplot2::aes_string(xmin = "Year1", 
@@ -505,24 +515,24 @@ gr_plot_periods <- function(df, ..., year = NULL, exclude = NULL, tests = NULL,
   if (grenv$loc != 'EN')
     labs = gr_unescape(labs)
   
-  fields = rlang::exprs(...) %>% as.character()
+  fields = rlang::exprs(...) |> as.character()
 
   if(length(fields) == 0)
-    fields = params_out %>% 
-    dplyr::filter(.data$Order != 0) %>% 
-    dplyr::arrange(.data$Order) %>% 
+    fields = params_out |> 
+    dplyr::filter(.data$Order != 0) |> 
+    dplyr::arrange(.data$Order) |> 
     dplyr::pull(.data$Name)
   
-  prms = params_out %>% 
-    dplyr::filter(.data$Name %in% fields) %>% 
+  prms = params_out |> 
+    dplyr::filter(.data$Name %in% fields) |> 
     dplyr::slice(match(fields,Name))
   
   if (is.logical(tests))
     if (tests == TRUE)
       tests = gr_test_vars(df, ...)
   
-  df = df %>% 
-    dplyr::filter(!(.data$Year1 %in% exclude)) %>% 
+  df = df |>  
+    dplyr::filter(!(.data$Year1 %in% exclude)) |>  
     dplyr::mutate_if(params_out$Winter == 1, replace_year)
   
   units = switch(grenv$loc,
@@ -549,14 +559,14 @@ gr_plot_periods <- function(df, ..., year = NULL, exclude = NULL, tests = NULL,
       year = tests$year[i]
     }
     
-    d = df[prms$Name[i]] %>% 
-      as.matrix() %>% 
+    d = df[prms$Name[i]] |> 
+      as.matrix() |> 
       as.vector()
     
     is_date = FALSE
     if(prms$Unitsen[i] %in% c('Date', 'Month')){
       
-      d = d %>% as.Date() 
+      d = d |> as.Date() 
       lubridate::year(d) <- 2000 # fake year
       
       if (prms$Winter[i] == 1)
@@ -589,7 +599,7 @@ gr_plot_periods <- function(df, ..., year = NULL, exclude = NULL, tests = NULL,
       ggplot2::theme(plot.title = ggplot2::element_text(size=12, lineheight=.8, face="bold"),
             panel.background = ggplot2::element_rect(fill = prms$Color[i],
                                             colour = prms$Color[i],
-                                            size = 0.5, linetype = "solid"))
+                                            linewidth = 0.5, linetype = "solid"))
     if (!is.null(exclude)) {
       g = g + 
         ggplot2::labs(caption = paste('Excluded years:', paste(exclude, collapse = ', '))) +
@@ -604,26 +614,26 @@ gr_plot_periods <- function(df, ..., year = NULL, exclude = NULL, tests = NULL,
       rsd1 = round(sd(d1, na.rm = TRUE)/m1, 3)
       rsd2 = round(sd(d2, na.rm = TRUE)/m2, 3)
       
-      means <- df.plot %>% 
-        dplyr::group_by(Period) %>% 
+      means <- df.plot |> 
+        dplyr::group_by(Period) |> 
         dplyr::summarise(Value = mean(Value, na.rm = TRUE))
       
       mean1 = ifelse(is_date, 
-                     m1 %>% as.integer() %>% as.Date(origin = '1970-01-01') %>% format("%d-%b"),
-                     m1 %>% round(3)
+                     m1 |> as.integer() |> as.Date(origin = '1970-01-01') |> format("%d-%b"),
+                     m1 |> round(3)
       )
       
       mean2 = ifelse(is_date, 
-                     m2 %>% as.integer() %>% as.Date(origin = '1970-01-01') %>% format("%d-%b"),
-                     m2 %>% round(3)
+                     m2 |> as.integer() |> as.Date(origin = '1970-01-01') |> format("%d-%b"),
+                     m2 |> round(3)
       )
       
       m1 = ifelse(is_date,
-                  m1 %>% as.integer(),
+                  m1 |> as.integer(),
                   m1)
       
       m2 = ifelse(is_date,
-                  m2 %>% as.integer(),
+                  m2 |> as.integer(),
                   m2)
       
       pt.df = data.frame(Value = c(m1, m2), 
@@ -648,7 +658,7 @@ gr_plot_periods <- function(df, ..., year = NULL, exclude = NULL, tests = NULL,
     
     if(is_date){
       g = g + ggplot2::scale_y_continuous(labels = function(x) {
-        return(as.Date(x, origin = "1970-01-01") %>% format(format = '%d-%m'))
+        return(as.Date(x, origin = "1970-01-01") |> format(format = '%d-%m'))
       })
     }
     
@@ -734,10 +744,10 @@ gr_plot_minmonth <- function(df, year = NULL, exclude = NULL, tests = NULL, page
   periodtitle1_winter = paste0(labs$beforetitle, year_winter)
   periodtitle2_winter = paste0(labs$aftertitle, year_winter)
   
-  chart.data = df %>% 
-    dplyr::filter(!(Year1 %in% exclude)) %>% 
-    dplyr::select(Dsmin, Dwmin, Year1) %>% 
-    dplyr::filter(!is.na(Dsmin) & !is.na(Dwmin)) %>% 
+  chart.data = df |> 
+    dplyr::filter(!(Year1 %in% exclude)) |> 
+    dplyr::select(Dsmin, Dwmin, Year1) |> 
+    dplyr::filter(!is.na(Dsmin) & !is.na(Dwmin)) |> 
     dplyr::mutate(summermonth = lubridate::month(Dsmin),
                   wintermonth = lubridate::month(Dwmin),
                   old_summer = as.integer(Year1 >= year_summer),
@@ -762,30 +772,30 @@ gr_plot_minmonth <- function(df, year = NULL, exclude = NULL, tests = NULL, page
                                    levels = c(7:12, 1:6), 
                                    labels = winterlabels)
   
-  df.summer = chart.data %>% 
-    dplyr::group_by(old_summer, summermonth) %>% 
-    dplyr::tally() %>% 
-    dplyr::ungroup() %>% 
-    tidyr::complete(summermonth, old_summer, fill = list(n=0)) %>%  
+  df.summer = chart.data |> 
+    dplyr::group_by(old_summer, summermonth) |> 
+    dplyr::tally() |> 
+    dplyr::ungroup() |> 
+    tidyr::complete(summermonth, old_summer, fill = list(n=0)) |>  
     dplyr::mutate(perc = 100*.data$n/sum(.data$n))
   
-  df.winter = chart.data %>% 
-    dplyr::group_by(old_winter, wintermonth) %>% 
-    dplyr::tally() %>% 
-    dplyr::ungroup() %>% 
-    tidyr::complete(wintermonth, old_winter, fill = list(n=0)) %>%  
+  df.winter = chart.data |> 
+    dplyr::group_by(old_winter, wintermonth) |> 
+    dplyr::tally() |> 
+    dplyr::ungroup() |> 
+    tidyr::complete(wintermonth, old_winter, fill = list(n=0)) |> 
     dplyr::mutate(perc = 100*n/sum(n))
   
-  df.summer.all = chart.data %>% 
-    dplyr::group_by(summermonth) %>% 
-    dplyr::tally() %>% 
-    dplyr::ungroup() %>%
+  df.summer.all = chart.data |> 
+    dplyr::group_by(summermonth) |> 
+    dplyr::tally() |> 
+    dplyr::ungroup() |>
     dplyr::mutate(perc = 100*n/sum(n))
   
-  df.winter.all = chart.data %>% 
-    dplyr::group_by(.data$wintermonth) %>% 
-    dplyr::tally() %>% 
-    dplyr::ungroup() %>%
+  df.winter.all = chart.data |> 
+    dplyr::group_by(.data$wintermonth) |> 
+    dplyr::tally() |> 
+    dplyr::ungroup() |>
     dplyr::mutate(perc = 100*.data$n/sum(.data$n))
   
   g.summer = ggplot2::ggplot() +
@@ -893,7 +903,7 @@ gr_plot_tests <- function(tests, type = 'year', print = TRUE) {
   plt = ggplot2::ggplot() +    
     ggplot2::geom_line(data = ddf, ggplot2::aes(x =year, y = dens), color = 'black') +
     ggplot2::geom_area(data = ddf, ggplot2::aes(x =year, y = dens), alpha = 0.2) +
-    ggplot2::geom_vline(xintercept = modeval, color = "steelblue4", size = 1) +
+    ggplot2::geom_vline(xintercept = modeval, color = "steelblue4", linewidth = 1) +
     ggplot2::annotate("text", label = modeval, 
              x = modeval + 0.05 * (max(dens$x) - min(dens$x)), y = 0.01, 
              size = 5, colour = "steelblue4") +
@@ -927,13 +937,13 @@ gr_plot_tests <- function(tests, type = 'year', print = TRUE) {
 #' 
 gr_plot_acf <- function(hdata, autocorr = 0.7, maxlag = 30, print = TRUE) {
   
-  max_period = hdata %>% 
-    grwat::gr_get_gaps() %>% 
+  max_period = hdata |> 
+    grwat::gr_get_gaps() |> 
     dplyr::filter(.data$type == 'data',duration == max(.data$duration))
   
-  acf_data = hdata %>% 
-    dplyr::rename(Date = 1) %>% 
-    dplyr::filter(dplyr::between(.data$Date, max_period$start_date, max_period$end_date)) %>% 
+  acf_data = hdata |> 
+    dplyr::rename(Date = 1) |> 
+    dplyr::filter(dplyr::between(.data$Date, max_period$start_date, max_period$end_date)) |> 
     dplyr::pull(2)
   
   afun = acf(acf_data, lag.max = maxlag, plot = FALSE)
@@ -1152,10 +1162,10 @@ gr_plot_ridge <- function(df, years, pal = 4, rev = FALSE, scale = 0.01, alpha =
   if (grenv$loc != 'EN')
     labs = gr_unescape(labs)
   
-  df_sel = df %>%
-    dplyr::rename(Date = 1, Q = 2) %>%
+  df_sel = df |>
+    dplyr::rename(Date = 1, Q = 2) |>
     dplyr::mutate(Year = lubridate::year(.data$Date),
-                  Datefake = lubridate::ymd(20000101) + lubridate::yday(.data$Date)) %>%
+                  Datefake = lubridate::ymd(20000101) + lubridate::yday(.data$Date)) |>
     dplyr::filter(.data$Year %in% years)
 
   plt = ggplot2::ggplot(df_sel, 
@@ -1224,10 +1234,10 @@ gr_plot_hori <- function(df, years, pal = 'Blues', rev = TRUE, scale = 6, print
   if (grenv$loc != 'EN')
     labs = gr_unescape(labs)
   
-  df_sel = df %>%
-    dplyr::rename(Date = 1, Q = 2) %>%
+  df_sel = df |>
+    dplyr::rename(Date = 1, Q = 2) |>
     dplyr::mutate(Year = lubridate::year(.data$Date),
-                  Datefake = lubridate::ymd(20000101) + lubridate::yday(.data$Date)) %>%
+                  Datefake = lubridate::ymd(20000101) + lubridate::yday(.data$Date)) |>
     dplyr::filter(.data$Year %in% years)
   
   plt = ggplot2::ggplot(df_sel,  ggplot2::aes(.data$Datefake,Q)) +
