@@ -158,9 +158,9 @@ gr_separate <- function(df, params = gr_get_params(), debug = FALSE) {
   
   gr_check_params(params, df)
   
-  df = df %>% 
-    dplyr::rename(Date = 1) %>% 
-    dplyr::filter(!is.na(.data$Date)) %>% 
+  df = df |> 
+    dplyr::rename(Date = 1) |> 
+    dplyr::filter(!is.na(.data$Date)) |> 
     tidyr::complete(Date = seq(min(.data$Date, na.rm = TRUE), max(.data$Date, na.rm = TRUE), by = 'day'))
   
   if (!is.list(params[[1]]))
@@ -172,9 +172,9 @@ gr_separate <- function(df, params = gr_get_params(), debug = FALSE) {
                df[[2]], df[[3]], df[[4]],
                params, debug) 
   
-  sep = dplyr::bind_cols(df, sepraw) %>%
-    dplyr::rename(Date = 1, Q = 2, Temp = 3, Prec = 4) %>%
-    # dplyr::relocate(.data$Temp, .data$Prec, .after = dplyr::last_col()) %>%
+  sep = dplyr::bind_cols(df, sepraw) |>
+    dplyr::rename(Date = 1, Q = 2, Temp = 3, Prec = 4) |>
+    # dplyr::relocate(.data$Temp, .data$Prec, .after = dplyr::last_col()) |>
     dplyr::mutate(dplyr::across(5:11, ~ replace(.x, .x < 0, NA)))
   
   if (debug) {
@@ -208,7 +208,7 @@ gr_separate <- function(df, params = gr_get_params(), debug = FALSE) {
 #' @param Q Numeric runoff vector.
 #' @param padding Integer number of elements padded at the beginning and ending of runoff vector to reduce boundary effects. Defaults to `30`.
 #' @param passes Integer number of filtering iterations. The first iteration is forward, second is backward, third is forward and so on. Defaults to `3`.
-#' @param method Character string to set baseflow filtering method. Available methods are `'boughton'`, `'chapman'`, `'furey'`, `'jakeman'`, `'lynehollick'` and `'maxwell'`. Default is `'lynehollick'`, which corresponds to Lyne-Hollick (1979) hydrograph separation method.
+#' @param method Character string to set baseflow filtering method. Available methods are `'boughton'`, `'chapman'`, `'jakeman'`, `'lynehollick'` and `'maxwell'`. Default is `'lynehollick'`, which corresponds to Lyne-Hollick (1979) hydrograph separation method.
 #' @param a Numeric value of a filtering parameter used in `'chapman'`, `'jakeman'` and `'lynehollick'` methods. Defaults to `0.925`.
 #' @param k Numeric value of a filtering parameter used in `'boughton'` and `'maxwell'` methods. Defaults to `0.975`.
 #' @param C Numeric value of a separation shape parameter used in `'boughton'`, `'jakeman'` and `'maxwell'` methods
@@ -239,14 +239,14 @@ gr_baseflow <- function(Q, a = 0.925, k = 0.975, C = 0.05, aq = -0.5,
 #' 
 gr_get_params <- function(reg = 'center', lon = NULL, lat = NULL) {
   if (reg %in% params_in$index) {
-    params_in %>% 
-      dplyr::filter(index == reg) %>% 
-      dplyr::select(-index, -region) %>%
+    params_in |> 
+      dplyr::filter(index == reg) |> 
+      dplyr::select(-index, -region) |>
       as.list()
   } else if (reg %in% params_in$region) {
-    params_in %>% 
-      dplyr::filter(region == reg) %>% 
-      dplyr::select(-index, -region) %>%
+    params_in |> 
+      dplyr::filter(region == reg) |> 
+      dplyr::select(-index, -region) |>
       as.list()
   } else if (is.numeric(lon) && is.numeric(lat) && !is.na(lon) && !is.na(lat)) {
     if (lon >= -180 && lon < 180 && lat >= -90 && lat <= 90) {
@@ -260,9 +260,9 @@ gr_get_params <- function(reg = 'center', lon = NULL, lat = NULL) {
           regions[reg[[1]], ],
           params_in,
           by = 'index'
-        ) %>% 
-          sf::st_drop_geometry() %>% 
-          dplyr::select(-index, -region) %>%
+        ) |> 
+          sf::st_drop_geometry() |> 
+          dplyr::select(-index, -region) |>
           as.list()
       } else {
         stop(cli::col_white(cli::bg_red(cli::style_bold('grwat:'))), 
@@ -314,4 +314,38 @@ gr_set_param <- function(params, p, value, years = NULL) {
   }
   
   return(params)
+}
+
+#' Convert list of parameters to data frame
+#'
+#' @param params `list` of `list`s of hydrograph separation parameters as returned in `params` attribute by [grwat::gr_separate()]  with `debug = TRUE`.
+#'
+#' @returns `tibble` data frame with tabular representation of hydrograph separation parameters
+#' @export
+#'
+#' @example inst/examples/gr_to_pardf.R
+gr_to_pardf <- function(params) {
+  do.call(dplyr::bind_rows, params) |> 
+    dplyr::mutate(year = as.integer(names(params))) |> 
+    dplyr::relocate(year, .before = 1)
+}
+
+#' Convert data frame of parameters to list
+#'
+#' @param pardf `tibble` data frame with tabular representation of hydrograph separation parameters as returned by [grwat::gr_to_pardf()].
+#'
+#' @returns `list` of `list`s of hydrograph separation parameters as returned in `params` attribute by [grwat::gr_separate()]  with `debug = TRUE`.
+#' @export
+#'
+#' @example inst/examples/gr_from_pardf.R
+gr_from_pardf <- function(pardf) {
+  pardf |> 
+    dplyr::select(-year) |> 
+    apply(1, as.list) |> 
+    lapply(\(X) {
+      n = length(X)
+      X[1:(n - 1)] <- lapply(X[1:(n - 1)], as.numeric)
+      return(X)
+    }) |> 
+    setNames(pardf$year)
 }
\ No newline at end of file
