@@ -20,9 +20,21 @@ print(jit)
 
 # actual params used for each year
 parlist = attributes(sep_debug)$params
-partab = do.call(dplyr::bind_rows, parlist) # View as table
+
+# tabular representation of parameters
+partab = gr_to_pardf(parlist)
 head(partab)
 
+parlist2 = partab |> 
+  dplyr::select(-year) |> 
+  apply(1, as.list) |> 
+  lapply(\(X) {
+    n = length(X)
+    X[1:(n - 1)] <- lapply(X[1:(n - 1)], as.numeric)
+    return(X)
+  }) |> 
+  setNames(partab$year)
+
 # extract and tweak parameters for selected year
 p = parlist[['1989']]
 p$grad1 = 1
